#
# spec file for package python3-pyside-shiboken
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pyside-shiboken
Version:        1.2.4
Release:        lp150.1.6
%define majorver   %(echo "%{version}" | sed 's/\\.[0-9]*$//')
%define libsoname  %(echo "%{majorver}" | sed 's/\\./_/')
%define libname   libshiboken-%{libsoname}_%{py3_soflags}%{libsoname}
Summary:        Generate CPython 3 bindings from C++ code
License:        GPL-2.0
Group:          Development/Libraries/C and C++
Url:            http://qt-project.org/wiki/PySide
Source0:        https://github.com/PySide/Shiboken/archive/%{version}/shiboken-%{version}.tar.gz
# PATCH-FIX shiboken-fix-include-with-suffix rpm@fthiessen.de -- fixes .pc so include directory with suffix will be found.
# Reported upstream: https://bugreports.qt.io/browse/PYSIDE-279
Patch0:         shiboken-fix-include-with-suffix.patch
# PATCH-FIX-UPSTREAM shiboken-enable-python35 toddrme2178@gmail.com -- enables building with python 3.5
# Reported upstream: https://github.com/PySide/Shiboken/issues/77
Patch1:         shiboken-enable-python35.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libqt4-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  python3-Sphinx
BuildRequires:  python3-devel
Requires:       %{libname} = %{version}
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
Shiboken generates C++ code for CPython extensions. It is similar to
BoostPythonGenerator from boost::python, but is designed to create smaller
code.

%package -n %{libname}
Summary:        Generate CPython 3 bindings from C++ code
License:        LGPL-2.1
Group:          Development/Libraries/C and C++

%description -n %{libname}
Shiboken generates C++ code for CPython extensions. It is similar to
BoostPythonGenerator from boost::python, but is designed to create smaller
code.

%package doc
Summary:        Documentation for %{name}
License:        GPL-2.0
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
Documentation and manuals for %{name}

%package -n libshiboken-python3-devel
Summary:        Development files for %{name}
License:        LGPL-2.1
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       cmake
Requires:       libqt4-devel
Requires:       libxml2-devel
Requires:       libxslt-devel
Requires:       python3-Sphinx
Requires:       python3-devel >= %{py3_ver}
# As cmake config files are not python version agnostic, python2 and 3 versions of developement
# package can't be installed at the same time
Conflicts:      libshiboken-devel

%description -n libshiboken-python3-devel
Development libraries and headers needed to build software using %{name}

%prep
%setup -q -n Shiboken-%{version}
%patch0 -p1
%patch1 -p1

%build
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DBUILD_TESTS=False \
       -DENABLE_VERSION_SUFFIX=True \
       -DUSE_PYTHON3=True
make %{?_smp_mflags}
make doc

%install
cd build
%makeinstall DESTDIR=%{buildroot}
mv %{buildroot}%{_bindir}/shiboken-%{majorver} %{buildroot}%{_bindir}/shiboken-%{py3_ver}
mv %{buildroot}%{_mandir}/man1/shiboken.1 %{buildroot}%{_mandir}/man1/shiboken-%{py3_ver}.1
%fdupes %{buildroot}
# openSUSE 13.1 and lower have a bad bug with brp-symlink
%if 0%{?suse_version} >= 1315
  ln -s %{_sysconfdir}/alternatives/shiboken      %{buildroot}%{_bindir}/shiboken
  ln -s %{_sysconfdir}/alternatives/shiboken.1    %{buildroot}%{_mandir}/man1/shiboken.1
  ln -s %{_sysconfdir}/alternatives/shiboken.1.gz %{buildroot}%{_mandir}/man1/shiboken.1.gz
  ln -s %{_sysconfdir}/alternatives/shiboken      %{buildroot}%{_bindir}/shiboken-%{majorver}
%endif

%pre
[ -h %{_bindir}/shiboken ] || rm -f %{_bindir}/shiboken
[ -h %{_mandir}/man1/shiboken.1.gz ] || rm -f %{_mandir}/man1/shiboken.1.gz

%post
/sbin/ldconfig
update-alternatives --install %{_bindir}/shiboken shiboken %{_bindir}/shiboken-%{py3_ver} 20 \
                    --slave %{_mandir}/man1/shiboken.1.gz shiboken.1 %{_mandir}/man1/shiboken-%{py3_ver}.1.gz \
                    --slave %{_bindir}/shiboken-%{majorver} shiboken-%{majorver} %{_bindir}/shiboken-%{py3_ver}

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove shiboken %{_bindir}/shiboken-%{py3_ver}
fi

%postun -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig
%post   -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING AUTHORS
%ghost %{_sysconfdir}/alternatives/shiboken
%ghost %{_sysconfdir}/alternatives/shiboken-%{majorver}
%ghost %{_sysconfdir}/alternatives/shiboken.1
%ghost %{_sysconfdir}/alternatives/shiboken.1.gz
%{_bindir}/shiboken*
%{_mandir}/man1/shiboken*.1.gz
%{python3_sitearch}/shiboken.so

%files -n %{libname}
%defattr(-,root,root)
%doc COPYING.libshiboken AUTHORS
%{_libdir}/libshiboken-%{majorver}.%{py3_soflags}.so.*

%files doc
%defattr(-,root,root)
%doc COPYING
%doc build/doc/html/*

%files -n libshiboken-python3-devel
%defattr(-,root,root)
%{_includedir}/shiboken-%{majorver}/
%{_libdir}/libshiboken-%{majorver}.%{py3_soflags}.so
%{_libdir}/cmake/Shiboken-%{version}/
%{_libdir}/pkgconfig/shiboken-%{majorver}.pc

%changelog
* Tue Mar  7 2017 adrian@suse.de
- fix build for python 3.6
* Thu Jan 28 2016 toddrme2178@gmail.com
- Add shiboken-enable-python35.patch to allow building on
  Python 3.5
- Fix and simplify macros
* Mon Oct 26 2015 rpm@fthiessen.de
- Updated to upstream release 1.2.4:
  * Don’t ignore classes in topology
  * Process global enums in declaration order
  * Return enums in declaration order (order added)
* Sun Jul 19 2015 rpm@fthiessen.de
- Added patch for fixing version suffix:
  shiboken-fix-include-with-suffix.patch
  Reported upstream: https://bugreports.qt.io/browse/PYSIDE-279
- Fixed alternatives for suffix version and removed some warnings
- Fixed "Conflicts": Can not be installed with python2 version of
  shiboken devel package.
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * update copyright year
  * remove ifs for opensuse version <=1220
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in pre script
* Thu May  8 2014 toddrme2178@gmail.com
- Update to 1.2.2
  * Fix building with python 3.3 and 3.4.
  * Refactor and improve added function resolving
  * Bug fixes.
- Remove upstream patch shiboken-1.2.1-cmake-find-python3.3.patch
* Fri Feb  7 2014 dimstar@opensuse.org
- Fix %%post scriptlets: /sbin/ldconfig can't be the parser of
  the script: it does not know how to do it (remove -p).
* Sun Dec 29 2013 p.drouand@gmail.com
- Implement update-alternative support to avoid conflict between
  python and python3 package on a same system
- Add a Conflict tag in devel subpackage in both python/3 package;
  Cmake config files are unfortunately not python-version agnostic
  and generate conflicts between the two packages
- Remove renaming of pkgconfig file in python3 package; it's not needed
  as the two packages are conflicting
* Thu Dec 19 2013 p.drouand@gmail.com
- Specfile clean-up
- Remove obsolete conditionnal macros
- Remove depreciated %%{py_requires} macro
- Fix Group; standard is Devel/Languages/Python
* Tue Aug 27 2013 fisiu@opensuse.org
- Update to 1.2.1:
  * Bug fixes.
  * Fix build in C++11 mode.
- Update tarball url.
- Rebase cmake-find-python3.3.patch.
* Thu Aug 15 2013 speilicke@suse.com
- Buildrequire python3-2to3 on 12.2
- Don't require python3-base, it's comes with python3-devel
* Fri Apr 12 2013 toddrme2178@gmail.com
- Added shiboken-1.1.2-cmake-find-python3.3.patch
  Fixes detecting python 3.3 with cmake
- Enable python3-Sphinx since it is available now
- Fix up spec file macros
* Wed Aug 29 2012 toddrme2178@gmail.com
- Update to 1.1.2
  * bugfix release
* Mon Apr 23 2012 toddrme2178@gmail.com
- Add python 3 package
